==> ejc-equipment-impl-3.0.0-20200715.092206-124-sources.jar: com/ejianc/business/equipment/service/impl/PurchaseContractBpmServiceImpl.java <==
package com.ejianc.business.equipment.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.equipment.bean.PurchaseContractEntity;
import com.ejianc.business.equipment.bean.PurchaseSettlementEntity;
import com.ejianc.business.equipment.service.IPurchaseContractService;
import com.ejianc.business.equipment.service.IPurchaseSettlementService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 设备合同审批操作后
 * </p>
 *
 * @author sunyj
 * @since 2020-06-18
 */
@Service("purchaseContract")
public class PurchaseContractBpmServiceImpl implements ICommonBusinessService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;

    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        //合同是否被其他单据引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            return CommonResponse.success();
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }
}

==> ejc-equipment-impl-3.0.0-20220801.091554-356-sources.jar: com/ejianc/business/equipment/service/impl/PurchaseContractBpmServiceImpl.java <==
package com.ejianc.business.equipment.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.equipment.bean.PurchaseContractEntity;
import com.ejianc.business.equipment.bean.PurchaseSettlementEntity;
import com.ejianc.business.equipment.service.IPurchaseContractService;
import com.ejianc.business.equipment.service.IPurchaseSettlementService;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 设备合同审批操作后
 * </p>
 *
 * @author sunyj
 * @since 2020-06-18
 */
@Service("purchaseContract")
public class PurchaseContractBpmServiceImpl implements ICommonBusinessService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;

    @Autowired
    private IOrgApi orgApi;

    @Autowired
    private IPurchaseContractService purchaseContractService;

    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        //合同是否被其他单据引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            //上级的集采合同不允许被撤回
            PurchaseContractEntity contractEntity = purchaseContractService.selectById(billId);
            Long conorgid = contractEntity.getOrgId();//合同组织主键
            CommonResponse<OrgVO> conResp =  orgApi.getOneById(conorgid);
            if(!conResp.isSuccess() || !conResp.isSuccess()) {
                return CommonResponse.error("查询合同组织信息失败！");
            }
            Long currentOrg = InvocationInfoProxy.getOrgId();
            String innerCode = conResp.getData().getInnerCode();
            if("2".equals(contractEntity.getPurchaseType())&&!innerCode.contains(String.valueOf(currentOrg))){
                 //说明-A组织innerCode包含了B主键，说明B是A的上级
                return CommonResponse.error("当前集采合同编制组织是【"+contractEntity.getOrgName()+"】，不可撤回！");
            }
            return CommonResponse.success();
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }
}
